@@ -44,23 +44,6 @@ Kamoso::Kamoso(WebcamControl *webcamControl)
 
     connect(m_webcamControl, &WebcamControl::photoTaken, this, &Kamoso::photoTaken);
     connect(&m_recordingTimer, &QTimer::timeout, this, &Kamoso::recordingTimeChanged);
-
-    if (Settings::saveUrl().isLocalFile()) {
-        const QDir dir(Settings::saveUrl().toLocalFile());
-        const auto dirlist = dir.entryInfoList({"*.jpg"}, QDir::Files, QDir::SortFlag::Time);
-        if (!dirlist.isEmpty())
-            m_sampleImagePath = dirlist.first().absoluteFilePath();
-    }
-
-    if (m_sampleImagePath.isEmpty()) {
-        QTemporaryFile* temporary = new QTemporaryFile(QDir::temp().absoluteFilePath("XXXXXX-sampleimage.jpg"), this);
-        temporary->open();
-        auto sampleIcon = QIcon::fromTheme(QStringLiteral("kde"));
-        sampleIcon.pixmap(200, 200).save(temporary);
-
-        m_sampleImagePath = temporary->fileName();
-        temporary->close();
-    }
 }
 
 Kamoso::~Kamoso() = default;
@@ -88,7 +71,7 @@ const QString Kamoso::takePhoto()
     }
 
     const QUrl path = fileNameSuggestion(saveUrl, "picture", "jpg");
-    m_webcamControl->takePhoto(path);
+    m_webcamControl->takePhoto(path, true);
 
     if (path.isLocalFile()) {
         m_sampleImagePath = path.toLocalFile();
@@ -147,3 +130,16 @@ void Kamoso::trashFiles(const QJsonArray& urls)
     KIO::FileUndoManager::self()->recordJob(KIO::FileUndoManager::Trash, list, QUrl("trash:/"), job);
 //     KJobWidgets::setWindow(job, window);
 }
+
+QString Kamoso::sampleImage()
+{
+    if (m_sampleImagePath.isEmpty()) {
+        QScopedPointer<QTemporaryFile> temporary(new QTemporaryFile(QDir::temp().absoluteFilePath("XXXXXX-sampleimage.jpg"), this));
+        temporary->open();
+        m_sampleImagePath = temporary->fileName();
+        temporary->close();
+
+        m_webcamControl->takePhoto(QUrl::fromLocalFile(m_sampleImagePath), false);
+    }
+    return m_sampleImagePath;
+}
